==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Basic';
$lang['uninstalled'] = 'Modulen avinstallerad.';
$lang['installed'] = 'Modulversion %s installerad.';
$lang['stripbackgroundtags'] = 'Ta bort bakgrundstaggar fr&aring;n CSS';
$lang['source_formatting_text'] = 'Formatera HTML-koden';
$lang['dropdownblockformats_text'] = 'Blockformat i rullgardinsmeny';
$lang['allowtables'] = 'Till&aring;t tabellfunktioner';
$lang['newlinestyle_text'] = 'Stil f&ouml;r ny rad';
$lang['pstyle'] = 'p-stil';
$lang['brstyle'] = 'br-stil';
$lang['usecompressiontext'] = 'Anv&auml;nd gz-komprimering';
$lang['usecompressionhelp'] = 'Detta kan snabba upp laddningen av TinyMCE, men det kan ocks&aring; f&ouml;rhindra att den laddas p&aring; vissa system. Anv&auml;nd med f&ouml;rsiktighet.';
$lang['forcedrootblocktext'] = 'Tvinga <p> rootblock';
$lang['forcedrootblockhelp'] = 'Forces the returned content to at least be enclosed in a <p>-tag';
$lang['filepickerstyle'] = 'Stil f&ouml;r filbl&auml;ddrare';
$lang['filepickersize'] = 'Storlek p&aring; filbl&auml;ddrare';
$lang['allowuploadtext'] = 'Till&aring;t uppladdning och skapande av mappar i Filbl&auml;ddraren';
$lang['cannotreadconfig'] = 'Kan inte l&auml;sa filen tinyconfig.php direkt, s&aring; TinyMCE kommer antagligen inte att fungera. Du b&ouml;r kontrollera r&auml;ttigheterna f&ouml;r den filen och dess &ouml;verliggande mappar, som alla b&ouml;r vara l&auml;sbara f&ouml;r alla men bara skrivbar f&ouml;r &auml;garen.';
$lang['filenameonly'] = 'Visa filnamn';
$lang['thumbnailsonly'] = 'Visa tumnagelbilder';
$lang['filenameandthumbnails'] = 'Visa b&aring;de filnamn och tumnagelbilder';
$lang['skinstext'] = 'Skal';
$lang['skinvariationtext'] = 'Skal-variant';
$lang['advancedwarning'] = '<strong>OBS!<br/>Om du &auml;ndrar de h&auml;r inst&auml;llningarna kan det g&ouml;ra att TinyMCE inte l&auml;ngre fungerar eller att den kod som genereras kan bli felaktig. &Auml;ndra bara detta om du vet vad du g&ouml;r! Kolla TinyMCE-webbsidan innan du g&ouml;r n&aring;gra &auml;ndringar h&auml;r.</strong>';
$lang['entityencoding_text'] = 'Kodning av entiteter';
$lang['rawencoding'] = 'R&aring;kodning (snabbast, fungerar i de flesta fall)';
$lang['namedencoding'] = 'Namnkodning (t.ex. &nbsp;)';
$lang['numericencoding'] = 'Numerisk kodning (t.ex.&amp;#160;)';
$lang['show_path_text'] = 'Visa s&ouml;kv&auml;gen till elementet under editorn.';
$lang['toolbar_tab'] = 'Verktygsf&auml;lt';
$lang['toolbar_help'] = 'De h&auml;r inst&auml;llningarna ska vara en kommaseparerad lista med namn p&aring; knappar/kontroller som ska vara med i verktygsf&auml;ltet.';
$lang['toolbar_text'] = 'Verktygsf&auml;lt';
$lang['toolbarhelptext'] = 'Klicka h&auml;r f&ouml;r att se verktygsf&auml;ltsinstruktioner i TinyMCE-wikin';
$lang['editor_width_text'] = 'Bredd p&aring; redigeringsf&auml;ltet';
$lang['editor_height_text'] = 'H&ouml;jd f&ouml;r redigeringsf&auml;ltet';
$lang['auto'] = 'Automatiskt';
$lang['or'] = 'eller';
$lang['datetimeformat_text'] = 'Format f&ouml;r datum/tid';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Datum';
$lang['datetimeformat_help'] = 'Klicka h&auml;r f&ouml;r hj&auml;lp om hur du formatterar datum/tid';
$lang['extraconfigtext'] = 'Extrainst&auml;llningar';
$lang['extraconfighelp'] = 'Kolla TinyMCE-wikin f&ouml;r instruktioner';
$lang['customdropdowntext'] = 'Anpassad dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup aktiverat';
$lang['startenabledhelp'] = 'Om denna inte &auml;r ikryssad kommer TinyMCE-redigerare att starta i inaktivt l&auml;ge. B&ouml;r anv&auml;ndas tillsammans med toggle-knappen (av/p&aring;).';
$lang['loadcmslinkertext'] = 'Ladda CMS-l&auml;nkaren';
$lang['loadcmslinkerhelp'] = 'Detta genererar den javascript-kod som beh&ouml;vs f&ouml;r att till&aring;ta &#039;cmslinker&#039; att l&auml;ggas till i ett verktygsf&auml;lt.';
$lang['cmslinkerstyletext'] = 'L&auml;nkstil f&ouml;r CMS-l&auml;nkaren';
$lang['cmsselflinkstyle'] = 'Stil f&ouml;r {cms_selflink}';
$lang['ahrefstyle'] = 'Stil f&ouml;r <a href>';
$lang['relativeurlstext'] = 'Generera relativa s&ouml;kv&auml;gar';
$lang['forcecleanpastetext'] = 'Tvinga rensning vid klistra in';
$lang['forcecleanpastehelp'] = 'Detta b&ouml;r aktiveras f&ouml;r att ta bort konstig formatteringskod n&auml;r man klistrar in fr&aring;n t.ex. Word';
$lang['bodycss_text'] = 'CSS f&ouml;r body-taggen';
$lang['bodycss_help'] = 'l&auml;mna tomt eller skriv DEFAULT f&ouml;r att anv&auml;nda sidans CSS';
$lang['includeonlyscreencss_text'] = 'Inkludera enbart sk&auml;rm-CSS';
$lang['includeonlyscreencss_help'] = 'Om detta v&auml;ljs till&aring;ts enbart de kopplade stilmallar som har screen-mediatypen vald att inkluderas i de stilar som TinyMCE hanterar.';
$lang['usestaticconfigtext'] = 'Anv&auml;nd statisk konfigurationsfil';
$lang['usestaticconfighelp'] = 'Detta kan vara bra f&ouml;r att Tiny ska fungera p&aring; system d&auml;r webbservern l&auml;gger till s&aring;nt som statistik mm till all output, vilket bryter den dynamiskt skapade javascriptskonfigurationsfilen';
$lang['usestaticconfigwarning'] = 'Varning! Du har aktiverat statisk konfigurationsfil, men din /tmp/-mapp &auml;r inte skrivbar. Dett hindrar modulen fr&aring;n att spara den statiska konfigurationsfilen och kommer troligen g&ouml;ra TinyMCE obrukbar.';
$lang['showtogglebutton_text'] = 'Visa knapp f&ouml;r att s&auml;tta p&aring;/st&auml;nga av WYSIWYG';
$lang['togglewysiwyg'] = 'S&auml;tt p&aring;/st&auml;ng av WYSIWYG';
$lang['styles_tab'] = 'CSS-stilar';
$lang['styles_help'] = 'Om du l&auml;mnar det f&ouml;rsta f&auml;ltet tomt kommer TinyMCE att analysera din CSS-fil och lista alla stilar som finns i den f&ouml;r anv&auml;ndaren. Om du bara vill att n&aring;gra stilar ska visas f&ouml;r anv&auml;ndaren, ange dem i formen &quot;Stil 1=stil1; Stil 2=stil2&quot; i det f&ouml;rsta f&auml;ltet nedan.<br /> I de &ouml;vriga f&auml;lten kan du ange CSS-stilar f&ouml;r tabeller, rader och celler som anv&auml;nds i motsvarande dialogf&ouml;nster. Om ett f&auml;lt &auml;r tomt kommer stilarna fr&aring;n de allm&auml;nna stilarna att anv&auml;ndas.';
$lang['css_styles_text'] = 'Allm&auml;nna';
$lang['accessdenied'] = '&Aring;tkomst nekad. Var god kontrollera dina r&auml;ttigheter.';
$lang['error'] = 'Fel!';
$lang['submit'] = 'V&auml;lj';
$lang['update'] = 'Uppdatera';
$lang['settings'] = 'Inst&auml;llningar';
$lang['settingssaved'] = 'Inst&auml;llningar sparade';
$lang['advancedsaved'] = 'Avancerade inst&auml;llningar sparade';
$lang['toolbarsaved'] = 'Verktygsf&auml;ltet sparades';
$lang['stylessaved'] = 'Stilar sparade';
$lang['testareatext'] = 'Testomr&aring;de, inget inneh&aring;ll kommer att p&aring;verkas om du leker med det h&auml;r...';
$lang['reset'] = '&Aring;terst&auml;ll standardinst&auml;llningar';
$lang['resetall'] = '&Aring;terst&auml;ll alla inst&auml;llningar till standard';
$lang['confirmreset'] = '&Auml;r du s&auml;ker p&aring; att du vill &aring;terst&auml;lla de h&auml;r inst&auml;llningarna till standardinst&auml;llningar?';
$lang['confirmresetall'] = '&Auml;r du s&auml;ker p&aring; att du vill &aring;terst&auml;lla ALLA inst&auml;llningar till standardinst&auml;llningar?';
$lang['settingsreset'] = 'De h&auml;r inst&auml;llningarna &aring;terst&auml;lldes till standardinst&auml;llningarna';
$lang['allsettingsreset'] = 'Alla inst&auml;llningar &aring;terst&auml;lldes till standardinst&auml;llningar';
$lang['upgraded'] = 'har uppgraderats till version %s';
$lang['customdropdown'] = 'Anpassad rullgardinsmeny';
$lang['cmsmslinker'] = 'Infoga l&auml;nk till CMSMS-sida';
$lang['backend_toolbars'] = 'Inst&auml;llningar f&ouml;r backend-verktygsf&auml;lt';
$lang['frontend_toolbars'] = 'Inst&auml;llningar f&ouml;r frontend-verktygsf&auml;lt';
$lang['plugins_tab'] = 'Till&auml;gg';
$lang['plugins_help'] = 'V&auml;lj vilka till&auml;gg som du vill aktivera. Dokumentation finns <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">h&auml;r</a>';
$lang['plugins_text'] = 'Till&auml;gg';
$lang['saveplugins'] = 'Spara till&auml;gg';
$lang['pluginssaved'] = 'Till&auml;gg sparade';
$lang['youareintext'] = 'Du &auml;r p&aring;';
$lang['extrastylestext'] = 'Till&auml;gg till stilmallar';
$lang['extrastyleshelp'] = 'CSS som l&auml;ggs till h&auml;r kommer att l&auml;ggas till stilmallen som l&auml;sees av TinyMCE efter att den har l&auml;st CMSMS-stilarna';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Ladda upp';
$lang['createnewdir'] = 'Ny mapp';
$lang['createdir'] = 'Skapa';
$lang['nodirname'] = 'Inget mappnamn angivet';
$lang['direxists'] = 'Mappnamnet finns redan';
$lang['newdircreated'] = 'Ny mapp skapad';
$lang['newdirfailed'] = 'Ett fel intr&auml;ffade n&auml;r mappen skulle skapas';
$lang['nofile'] = 'Ingen fil laddades upp';
$lang['filetoobig'] = 'Den uppladdade filen &auml;r f&ouml;r stor';
$lang['uploadfailed'] = 'Fel vid flytt av den uppladdade filen';
$lang['fileuploaded'] = 'Filen uppladdad';
$lang['filepickertitle'] = 'Filval f&ouml;r CMS Made Simple';
$lang['success'] = 'Lyckat';
$lang['fileoperations'] = 'Filoperationer';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Storlek';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avancerat';
$lang['help'] = '<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['utma'] = '156861353.1844854326557378000.1220712016.1233479596.1233505303.313';
$lang['utmz'] = '156861353.1233505303.313.30.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Basic';
$lang['uninstalled'] = 'Modulen avinstallerad.';
$lang['installed'] = 'Modulversion %s installerad.';
$lang['stripbackgroundtags'] = 'Ta bort bakgrundstaggar fr&aring;n CSS';
$lang['stiptags_help'] = 'Det h&auml;r alternativet f&ouml;rs&ouml;ker ta bort bakgrundstyp-inst&auml;llningar fr&aring;n stilmallen';
$lang['source_formatting_text'] = 'Formatera HTML-koden';
$lang['dropdownblockformats_text'] = 'Blockformat i rullgardinsmeny';
$lang['allowtables'] = 'Till&aring;t tabellfunktioner';
$lang['newlinestyle_text'] = 'Stil f&ouml;r ny rad';
$lang['pstyle'] = 'p-stil';
$lang['brstyle'] = 'br-stil';
$lang['usecompressiontext'] = 'Anv&auml;nd gz-komprimering';
$lang['usecompressionhelp'] = 'Detta kan snabba upp laddningen av TinyMCE, men det kan ocks&aring; f&ouml;rhindra att den laddas p&aring; vissa system. Anv&auml;nd med f&ouml;rsiktighet.';
$lang['forcedrootblocktext'] = 'Tvinga <p> rootblock';
$lang['forcedrootblockhelp'] = 'Forces the returned content to at least be enclosed in a &amp;lt;p&amp;gt;-tagg';
$lang['filepickerstyle'] = 'Stil f&ouml;r filbl&auml;ddrare';
$lang['filepickersize'] = 'Storlek p&aring; filbl&auml;ddrare';
$lang['allowuploadtext'] = 'Till&aring;t uppladdning och skapande av mappar i Filbl&auml;ddraren';
$lang['allowscalingtext'] = 'Allow on-the-fly resizing of uploaded files';
$lang['scalingdimensionstext'] = 'Standard dimensioner';
$lang['resizeto'] = '&Auml;ndra storlek till:';
$lang['useadvancedprofile'] = 'Anv&auml;nd avancerad TinyMCE-profil';
$lang['saveprofile'] = 'Spara profil';
$lang['profilesaved'] = 'Profilen sparades';
$lang['profiles_tab'] = 'Profiler';
$lang['advanced_backend_toolbars'] = 'Avancerade profilinst&auml;llningar';
$lang['savestyles'] = 'Spara stilar';
$lang['allowadvancedprofile'] = 'Till&aring;t anv&auml;ndning av avancerade profiler i TinyMCE';
$lang['showfilemanagement'] = 'Visa inst&auml;llningar f&ouml;r filhantering';
$lang['showfilemanagementhelp'] = 'Visa filhantering i tillvalen f&ouml;r uppladdning, skapa mapp och borttagning av fil i Filv&auml;ljaren, om anv&auml;ndaren har r&auml;tt att g&ouml;ra detta.';
$lang['deleteconfirmation'] = '&Auml;r du s&auml;ker p&aring; att den h&auml;r filen ska raderas?';
$lang['deletefilesuccess'] = 'Blev framg&aring;ngsrikt raderad';
$lang['deletefilefila'] = 'Kunde inte raderas';
$lang['cannotreadconfig'] = 'Kan inte l&auml;sa filen tinyconfig.php direkt, s&aring; TinyMCE kommer antagligen inte att fungera. Du b&ouml;r kontrollera r&auml;ttigheterna f&ouml;r den filen och dess &ouml;verliggande mappar, som alla b&ouml;r vara l&auml;sbara f&ouml;r alla men bara skrivbar f&ouml;r &auml;garen.';
$lang['filenameonly'] = 'Visa filnamn';
$lang['thumbnailsonly'] = 'Visa tumnagelbilder';
$lang['showthumbnailfilestext'] = 'Visa tumnagelbilder i listor';
$lang['filenameandthumbnails'] = 'Visa b&aring;de filnamn och tumnagelbilder';
$lang['skinstext'] = 'Skal';
$lang['skinvariationtext'] = 'Skal-variant';
$lang['advancedwarning'] = '<strong>OBS!<br/>Om du &auml;ndrar de h&auml;r inst&auml;llningarna kan det g&ouml;ra att TinyMCE inte l&auml;ngre fungerar eller att den kod som genereras kan bli felaktig. &Auml;ndra bara detta om du vet vad du g&ouml;r! Kolla TinyMCE-webbsidan innan du g&ouml;r n&aring;gra &auml;ndringar h&auml;r.</strong>';
$lang['entityencoding_text'] = 'Kodning av entiteter';
$lang['rawencoding'] = 'R&aring;kodning (snabbast, fungerar i de flesta fall)';
$lang['namedencoding'] = 'Namnkodning (t.ex. &nbsp;)';
$lang['numericencoding'] = 'Numerisk kodning (t.ex.&amp;#160;)';
$lang['show_path_text'] = 'Visa s&ouml;kv&auml;gen till elementet under editorn.';
$lang['toolbar_tab'] = 'Verktygsf&auml;lt';
$lang['toolbar_help'] = 'De h&auml;r inst&auml;llningarna ska vara en kommaseparerad lista med namn p&aring; knappar/kontroller som ska vara med i verktygsf&auml;ltet.';
$lang['toolbar_text'] = 'Verktygsf&auml;lt';
$lang['toolbarhelptext'] = 'Klicka h&auml;r f&ouml;r att se verktygsf&auml;ltsinstruktioner i TinyMCE-wikin';
$lang['editor_width_text'] = 'Bredd p&aring; redigeringsf&auml;ltet';
$lang['editor_height_text'] = 'H&ouml;jd f&ouml;r redigeringsf&auml;ltet';
$lang['auto'] = 'Automatiskt';
$lang['or'] = 'eller';
$lang['datetimeformat_text'] = 'Format f&ouml;r datum/tid';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Datum';
$lang['datetimeformat_help'] = 'Klicka h&auml;r f&ouml;r hj&auml;lp om hur du formatterar datum/tid';
$lang['extraconfigtext'] = 'Extrainst&auml;llningar';
$lang['extraconfighelp'] = 'Kolla TinyMCE-wikin f&ouml;r instruktioner';
$lang['customdropdowntext'] = 'Anpassad dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup aktiverat';
$lang['startenabledhelp'] = 'Om denna inte &auml;r ikryssad kommer TinyMCE-redigerare att starta i inaktivt l&auml;ge. B&ouml;r anv&auml;ndas tillsammans med toggle-knappen (av/p&aring;).';
$lang['loadcmslinkertext'] = 'Ladda CMS-l&auml;nkaren';
$lang['loadcmslinkerhelp'] = 'Detta genererar den javascript-kod som beh&ouml;vs f&ouml;r att till&aring;ta &#039;cmslinker&#039; att l&auml;ggas till i ett verktygsf&auml;lt.';
$lang['cmslinkerstyletext'] = 'L&auml;nkstil f&ouml;r CMS-l&auml;nkaren';
$lang['cmsselflinkstyle'] = 'Stil f&ouml;r {cms_selflink}';
$lang['ahrefstyle'] = 'Stil f&ouml;r <a href>';
$lang['relativeurlstext'] = 'Generera relativa s&ouml;kv&auml;gar';
$lang['forcecleanpastetext'] = 'Tvinga rensning vid klistra in';
$lang['forcecleanpastehelp'] = 'Detta b&ouml;r aktiveras f&ouml;r att ta bort konstig formatteringskod n&auml;r man klistrar in fr&aring;n t.ex. Word';
$lang['bodycss_text'] = 'CSS f&ouml;r body-taggen';
$lang['bodycss_help'] = 'l&auml;mna tomt eller skriv DEFAULT f&ouml;r att anv&auml;nda sidans CSS';
$lang['includeonlyscreencss_text'] = 'Inkludera enbart sk&auml;rm-CSS';
$lang['includeonlyscreencss_help'] = 'Om detta v&auml;ljs till&aring;ts enbart de kopplade stilmallar som har screen-mediatypen vald att inkluderas i de stilar som TinyMCE hanterar.';
$lang['usestaticconfigtext'] = 'Anv&auml;nd statisk konfigurationsfil';
$lang['usestaticconfighelp'] = 'Detta kan vara bra f&ouml;r att Tiny ska fungera p&aring; system d&auml;r webbservern l&auml;gger till s&aring;nt som statistik mm till all output, vilket bryter den dynamiskt skapade javascriptskonfigurationsfilen';
$lang['usestaticconfigwarning'] = 'Varning! Du har aktiverat statisk konfigurationsfil, men din /tmp/-mapp &auml;r inte skrivbar. Dett hindrar modulen fr&aring;n att spara den statiska konfigurationsfilen och kommer troligen g&ouml;ra TinyMCE obrukbar.';
$lang['showtogglebutton_text'] = 'Visa knapp f&ouml;r att s&auml;tta p&aring;/st&auml;nga av WYSIWYG';
$lang['togglewysiwyg'] = 'S&auml;tt p&aring;/st&auml;ng av WYSIWYG';
$lang['styles_tab'] = 'CSS-stilar';
$lang['styles_help'] = 'Om du l&auml;mnar det f&ouml;rsta f&auml;ltet tomt kommer TinyMCE att analysera din CSS-fil och lista alla stilar som finns i den f&ouml;r anv&auml;ndaren. Om du bara vill att n&aring;gra stilar ska visas f&ouml;r anv&auml;ndaren, ange dem i formen &quot;Stil 1=stil1; Stil 2=stil2&quot; i det f&ouml;rsta f&auml;ltet nedan.<br /> I de &ouml;vriga f&auml;lten kan du ange CSS-stilar f&ouml;r tabeller, rader och celler som anv&auml;nds i motsvarande dialogf&ouml;nster. Om ett f&auml;lt &auml;r tomt kommer stilarna fr&aring;n de allm&auml;nna stilarna att anv&auml;ndas.';
$lang['css_styles_text'] = 'Allm&auml;nna';
$lang['accessdenied'] = '&Aring;tkomst nekad. Var god kontrollera dina r&auml;ttigheter.';
$lang['error'] = 'Fel!';
$lang['submit'] = 'V&auml;lj';
$lang['update'] = 'Uppdatera';
$lang['savesettings'] = 'Spara inst&auml;llningar';
$lang['settings'] = 'Inst&auml;llningar';
$lang['settingssaved'] = 'Inst&auml;llningar sparade';
$lang['saveadvanced'] = 'Spara anvancerade inst&auml;llningar';
$lang['advancedsaved'] = 'Avancerade inst&auml;llningar sparade';
$lang['toolbarsaved'] = 'Verktygsf&auml;ltet sparades';
$lang['stylessaved'] = 'Stilar sparade';
$lang['testareatext'] = '<p>Testomr&aring;de, inget inneh&aring;ll kommer att p&aring;verkas om du leker med det h&auml;r...</p>';
$lang['reset'] = '&Aring;terst&auml;ll standardinst&auml;llningar';
$lang['resetall'] = '&Aring;terst&auml;ll alla inst&auml;llningar till standard';
$lang['confirmreset'] = '&Auml;r du s&auml;ker p&aring; att du vill &aring;terst&auml;lla de h&auml;r inst&auml;llningarna till standardinst&auml;llningar?';
$lang['confirmresetall'] = '&Auml;r du s&auml;ker p&aring; att du vill &aring;terst&auml;lla ALLA inst&auml;llningar till standardinst&auml;llningar?';
$lang['settingsreset'] = 'De h&auml;r inst&auml;llningarna &aring;terst&auml;lldes till standardinst&auml;llningarna';
$lang['allsettingsreset'] = 'Alla inst&auml;llningar &aring;terst&auml;lldes till standardinst&auml;llningar';
$lang['upgraded'] = 'har uppgraderats till version %s';
$lang['customdropdown'] = 'Anpassad rullgardinsmeny';
$lang['cmsmslinker'] = 'Infoga l&auml;nk till CMSMS-sida';
$lang['backend_toolbars'] = 'Inst&auml;llningar f&ouml;r backend-verktygsf&auml;lt';
$lang['frontend_toolbars'] = 'Inst&auml;llningar f&ouml;r frontend-verktygsf&auml;lt';
$lang['plugins_tab'] = 'Till&auml;gg';
$lang['plugins_help'] = 'V&auml;lj vilka till&auml;gg som du vill aktivera. Dokumentation finns <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">h&auml;r</a>';
$lang['plugins_text'] = 'Till&auml;gg';
$lang['saveplugins'] = 'Spara till&auml;gg';
$lang['pluginssaved'] = 'Till&auml;gg sparade';
$lang['youareintext'] = 'Du &auml;r p&aring;';
$lang['loadstylesheettext'] = 'Ladda stilmall f&ouml;r inneh&aring;ll (rekommenderat)';
$lang['extrastylestext'] = 'Till&auml;gg till stilmallar';
$lang['extrastyleshelp'] = 'CSS som l&auml;ggs till h&auml;r kommer att l&auml;ggas till stilmallen som l&auml;sees av TinyMCE efter att den har l&auml;st CMSMS-stilarna';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Ladda upp';
$lang['createnewdir'] = 'Ny mapp';
$lang['createdir'] = 'Skapa';
$lang['nodirname'] = 'Inget mappnamn angivet';
$lang['direxists'] = 'Mappnamnet finns redan';
$lang['newdircreated'] = 'Ny mapp skapad';
$lang['newdirfailed'] = 'Ett fel intr&auml;ffade n&auml;r mappen skulle skapas';
$lang['nofile'] = 'Ingen fil laddades upp';
$lang['filetoobig'] = 'Den uppladdade filen &auml;r f&ouml;r stor';
$lang['uploadfailed'] = 'Fel vid flytt av den uppladdade filen';
$lang['fileuploaded'] = 'Filen uppladdad';
$lang['filepickertitle'] = 'Filval f&ouml;r CMS Made Simple';
$lang['success'] = 'Lyckat';
$lang['fileoperations'] = 'Filoperationer';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Storlek';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avancerat';
$lang['help'] = '<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>';
$lang['utmc'] = '156861353';
$lang['utma'] = '156861353.415365204.1233508366.1239119741.1242658766.11';
$lang['utmz'] = '156861353.1242658766.11.8.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
$lang['utmb'] = '156861353.1.10.1242658766';
?>
